==> batik_1.5.1.orig.tar.gz: batik-1.5.1.orig/test-sources/org/apache/batik/svggen/BasicShapes2.java <==
/*

 ============================================================================
                   The Apache Software License, Version 1.1
 ============================================================================

 Copyright (C) 1999-2003 The Apache Software Foundation. All rights reserved.

 Redistribution and use in source and binary forms, with or without modifica-
 tion, are permitted provided that the following conditions are met:

 1. Redistributions of  source code must  retain the above copyright  notice,
    this list of conditions and the following disclaimer.

 2. Redistributions in binary form must reproduce the above copyright notice,
    this list of conditions and the following disclaimer in the documentation
    and/or other materials provided with the distribution.

 3. The end-user documentation included with the redistribution, if any, must
    include  the following  acknowledgment:  "This product includes  software
    developed  by the  Apache Software Foundation  (http://www.apache.org/)."
    Alternately, this  acknowledgment may  appear in the software itself,  if
    and wherever such third-party acknowledgments normally appear.

 4. The names "Batik" and  "Apache Software Foundation" must  not  be
    used to  endorse or promote  products derived from  this software without
    prior written permission. For written permission, please contact
    apache@apache.org.

 5. Products  derived from this software may not  be called "Apache", nor may
    "Apache" appear  in their name,  without prior written permission  of the
    Apache Software Foundation.

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED WARRANTIES,
 INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 FITNESS  FOR A PARTICULAR  PURPOSE ARE  DISCLAIMED.  IN NO  EVENT SHALL  THE
 APACHE SOFTWARE  FOUNDATION  OR ITS CONTRIBUTORS  BE LIABLE FOR  ANY DIRECT,
 INDIRECT, INCIDENTAL, SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL  DAMAGES (INCLU-
 DING, BUT NOT LIMITED TO, PROCUREMENT  OF SUBSTITUTE GOODS OR SERVICES; LOSS
 OF USE, DATA, OR  PROFITS; OR BUSINESS  INTERRUPTION)  HOWEVER CAUSED AND ON
 ANY  THEORY OF LIABILITY,  WHETHER  IN CONTRACT,  STRICT LIABILITY,  OR TORT
 (INCLUDING  NEGLIGENCE OR  OTHERWISE) ARISING IN  ANY WAY OUT OF THE  USE OF
 THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 This software  consists of voluntary contributions made  by many individuals
 on  behalf of the Apache Software  Foundation. For more  information on the
 Apache Software Foundation, please see <http://www.apache.org/>.

*/

package org.apache.batik.svggen;

import java.awt.*;
import java.awt.geom.*;

/**
 * This test validates the convertion of Java 2D shapes into SVG
 * Shapes.
 *
 * @author <a href="mailto:cjolif@ilog.fr">Christophe Jolif</a>
 * @author <a href="mailto:vhardy@eng.sun.com">Vincent Hardy</a>
 * @version $Id: BasicShapes2.java,v 1.2 2003/08/08 11:39:38 vhardy Exp $
 */
public class BasicShapes2 implements Painter {
    public void paint(Graphics2D g) {
        g.setRenderingHint(RenderingHints.KEY_ANTIALIASING,
                           RenderingHints.VALUE_ANTIALIAS_ON);

        g.setPaint(Color.black);

        // Arc2D
        g.drawString("Arc2D", 10, 20);
        Arc2D arc = new Arc2D.Float(10, 30, 50, 40, 0, 270, Arc2D.PIE);
        g.draw(arc);

        g.translate(0, 90);

        // Ellipse
        g.drawString("Ellipse", 10, 20);
        Ellipse2D ellipse = new Ellipse2D.Double(10, 30, 100, 40);
        g.draw(ellipse);

        g.translate(150, -90);

        // GeneralPath lineTo
        g.drawString("GeneralPath, lineTo", 10, 20);
        GeneralPath lineToPath = new GeneralPath();
        lineToPath.moveTo(10, 30);
        lineToPath.lineTo(60, 30);
        lineToPath.lineTo(60, 70);
        lineToPath.lineTo(10, 30);
        lineToPath.closePath();
        g.draw(lineToPath);

        g.translate(0, 90);

        // GeneralPath curveTo
        g.drawString("GeneralPath, curveTo", 10, 20);
        GeneralPath curveToPath = new GeneralPath();
        curveToPath.moveTo(10, 30);
        curveToPath.curveTo(35, 10, 35, 50, 60, 30);
        curveToPath.curveTo(80, 55, 40, 55, 60, 80);
        curveToPath.curveTo(35, 60, 35, 100, 10, 80);
        curveToPath.curveTo(-10, 55, 30, 55, 10, 30);
        curveToPath.closePath();
        g.draw(curveToPath);
    }
}

==> batik_1.6.orig.tar.gz: batik-1.6.orig/test-sources/org/apache/batik/svggen/BasicShapes2.java <==
/*

   Copyright 2001  The Apache Software Foundation 

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

 */
package org.apache.batik.svggen;

import java.awt.*;
import java.awt.geom.*;

/**
 * This test validates the convertion of Java 2D shapes into SVG
 * Shapes.
 *
 * @author <a href="mailto:cjolif@ilog.fr">Christophe Jolif</a>
 * @author <a href="mailto:vhardy@eng.sun.com">Vincent Hardy</a>
 * @version $Id: BasicShapes2.java,v 1.3 2004/08/18 07:16:43 vhardy Exp $
 */
public class BasicShapes2 implements Painter {
    public void paint(Graphics2D g) {
        g.setRenderingHint(RenderingHints.KEY_ANTIALIASING,
                           RenderingHints.VALUE_ANTIALIAS_ON);

        g.setPaint(Color.black);

        // Arc2D
        g.drawString("Arc2D", 10, 20);
        Arc2D arc = new Arc2D.Float(10, 30, 50, 40, 0, 270, Arc2D.PIE);
        g.draw(arc);

        g.translate(0, 90);

        // Ellipse
        g.drawString("Ellipse", 10, 20);
        Ellipse2D ellipse = new Ellipse2D.Double(10, 30, 100, 40);
        g.draw(ellipse);

        g.translate(150, -90);

        // GeneralPath lineTo
        g.drawString("GeneralPath, lineTo", 10, 20);
        GeneralPath lineToPath = new GeneralPath();
        lineToPath.moveTo(10, 30);
        lineToPath.lineTo(60, 30);
        lineToPath.lineTo(60, 70);
        lineToPath.lineTo(10, 30);
        lineToPath.closePath();
        g.draw(lineToPath);

        g.translate(0, 90);

        // GeneralPath curveTo
        g.drawString("GeneralPath, curveTo", 10, 20);
        GeneralPath curveToPath = new GeneralPath();
        curveToPath.moveTo(10, 30);
        curveToPath.curveTo(35, 10, 35, 50, 60, 30);
        curveToPath.curveTo(80, 55, 40, 55, 60, 80);
        curveToPath.curveTo(35, 60, 35, 100, 10, 80);
        curveToPath.curveTo(-10, 55, 30, 55, 10, 30);
        curveToPath.closePath();
        g.draw(curveToPath);
    }
}
